@@ -2,7 +2,7 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2011 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -144,6 +144,9 @@ things.
                 auto_create => 1
             },
         ],
+        accept => [ 
+            'foo.*' => { type => 'leaf', value_type => 'uniline'}
+        ],
         element => [
             tree_macro => {
                 type       => 'leaf',
@@ -319,6 +322,14 @@ things.
                 description =>
                   'my_plain_check_list nto so helpfull description',
             },
+            enum_with_help_and_long_desc => {
+                type   => 'leaf',
+                value_type => 'enum' ,
+                choice => [ 'AA' .. 'AE' ],
+                help   => { map { ( $_ => "$_ help") ;} ('AA' .. 'AE') },
+                description =>
+                  "my_plain_check_list not so helpful\n even if long description",
+            },
            my_ref_check_list => {
                 type     => 'check_list',
                 refer_to => '- hash_a + ! hash_b',
